# coding: utf-8

"""
    mongodb

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeDBInstancesRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'create_end_time': 'str',
        'create_start_time': 'str',
        'db_engine': 'str',
        'db_engine_version': 'str',
        'instance_id': 'str',
        'instance_name': 'str',
        'instance_status': 'str',
        'instance_type': 'str',
        'page_number': 'int',
        'page_size': 'int',
        'tag_filters': 'list[TagFilterForDescribeDBInstancesInput]',
        'update_end_time': 'str',
        'update_start_time': 'str',
        'vpc_id': 'str',
        'zone_id': 'str'
    }

    attribute_map = {
        'create_end_time': 'CreateEndTime',
        'create_start_time': 'CreateStartTime',
        'db_engine': 'DBEngine',
        'db_engine_version': 'DBEngineVersion',
        'instance_id': 'InstanceId',
        'instance_name': 'InstanceName',
        'instance_status': 'InstanceStatus',
        'instance_type': 'InstanceType',
        'page_number': 'PageNumber',
        'page_size': 'PageSize',
        'tag_filters': 'TagFilters',
        'update_end_time': 'UpdateEndTime',
        'update_start_time': 'UpdateStartTime',
        'vpc_id': 'VpcId',
        'zone_id': 'ZoneId'
    }

    def __init__(self, create_end_time=None, create_start_time=None, db_engine=None, db_engine_version=None, instance_id=None, instance_name=None, instance_status=None, instance_type=None, page_number=None, page_size=None, tag_filters=None, update_end_time=None, update_start_time=None, vpc_id=None, zone_id=None, _configuration=None):  # noqa: E501
        """DescribeDBInstancesRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._create_end_time = None
        self._create_start_time = None
        self._db_engine = None
        self._db_engine_version = None
        self._instance_id = None
        self._instance_name = None
        self._instance_status = None
        self._instance_type = None
        self._page_number = None
        self._page_size = None
        self._tag_filters = None
        self._update_end_time = None
        self._update_start_time = None
        self._vpc_id = None
        self._zone_id = None
        self.discriminator = None

        if create_end_time is not None:
            self.create_end_time = create_end_time
        if create_start_time is not None:
            self.create_start_time = create_start_time
        if db_engine is not None:
            self.db_engine = db_engine
        if db_engine_version is not None:
            self.db_engine_version = db_engine_version
        if instance_id is not None:
            self.instance_id = instance_id
        if instance_name is not None:
            self.instance_name = instance_name
        if instance_status is not None:
            self.instance_status = instance_status
        if instance_type is not None:
            self.instance_type = instance_type
        if page_number is not None:
            self.page_number = page_number
        if page_size is not None:
            self.page_size = page_size
        if tag_filters is not None:
            self.tag_filters = tag_filters
        if update_end_time is not None:
            self.update_end_time = update_end_time
        if update_start_time is not None:
            self.update_start_time = update_start_time
        if vpc_id is not None:
            self.vpc_id = vpc_id
        if zone_id is not None:
            self.zone_id = zone_id

    @property
    def create_end_time(self):
        """Gets the create_end_time of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The create_end_time of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._create_end_time

    @create_end_time.setter
    def create_end_time(self, create_end_time):
        """Sets the create_end_time of this DescribeDBInstancesRequest.


        :param create_end_time: The create_end_time of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._create_end_time = create_end_time

    @property
    def create_start_time(self):
        """Gets the create_start_time of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The create_start_time of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._create_start_time

    @create_start_time.setter
    def create_start_time(self, create_start_time):
        """Sets the create_start_time of this DescribeDBInstancesRequest.


        :param create_start_time: The create_start_time of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._create_start_time = create_start_time

    @property
    def db_engine(self):
        """Gets the db_engine of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The db_engine of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._db_engine

    @db_engine.setter
    def db_engine(self, db_engine):
        """Sets the db_engine of this DescribeDBInstancesRequest.


        :param db_engine: The db_engine of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["MongoDB"]  # noqa: E501
        if (self._configuration.client_side_validation and
                db_engine not in allowed_values):
            raise ValueError(
                "Invalid value for `db_engine` ({0}), must be one of {1}"  # noqa: E501
                .format(db_engine, allowed_values)
            )

        self._db_engine = db_engine

    @property
    def db_engine_version(self):
        """Gets the db_engine_version of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The db_engine_version of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._db_engine_version

    @db_engine_version.setter
    def db_engine_version(self, db_engine_version):
        """Sets the db_engine_version of this DescribeDBInstancesRequest.


        :param db_engine_version: The db_engine_version of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["MongoDB_4_0", "MongoDB_5_0"]  # noqa: E501
        if (self._configuration.client_side_validation and
                db_engine_version not in allowed_values):
            raise ValueError(
                "Invalid value for `db_engine_version` ({0}), must be one of {1}"  # noqa: E501
                .format(db_engine_version, allowed_values)
            )

        self._db_engine_version = db_engine_version

    @property
    def instance_id(self):
        """Gets the instance_id of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The instance_id of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this DescribeDBInstancesRequest.


        :param instance_id: The instance_id of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def instance_name(self):
        """Gets the instance_name of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The instance_name of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this DescribeDBInstancesRequest.


        :param instance_name: The instance_name of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                instance_name is not None and len(instance_name) > 64):
            raise ValueError("Invalid value for `instance_name`, length must be less than or equal to `64`")  # noqa: E501

        self._instance_name = instance_name

    @property
    def instance_status(self):
        """Gets the instance_status of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The instance_status of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_status

    @instance_status.setter
    def instance_status(self, instance_status):
        """Sets the instance_status of this DescribeDBInstancesRequest.


        :param instance_status: The instance_status of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["AllowListMaintaining", "Closed", "Closing", "CreateFailed", "Creating", "Deleted", "Deleting", "Destroyed", "Destroying", "Error", "Importing", "Migrating", "NetCreating", "NetReleasing", "NetworkMaintaining", "Rebuilding", "Reclaiming", "Recycled", "Released", "Restarting", "Restoring", "Resuming", "Running", "SSLUpdating", "Scaling", "TDEMaintaining", "TaskFailed_Available", "Unavailable", "Updating", "Upgrading", "WaitingPaid"]  # noqa: E501
        if (self._configuration.client_side_validation and
                instance_status not in allowed_values):
            raise ValueError(
                "Invalid value for `instance_status` ({0}), must be one of {1}"  # noqa: E501
                .format(instance_status, allowed_values)
            )

        self._instance_status = instance_status

    @property
    def instance_type(self):
        """Gets the instance_type of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The instance_type of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type):
        """Sets the instance_type of this DescribeDBInstancesRequest.


        :param instance_type: The instance_type of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["ReplicaSet", "ShardedCluster"]  # noqa: E501
        if (self._configuration.client_side_validation and
                instance_type not in allowed_values):
            raise ValueError(
                "Invalid value for `instance_type` ({0}), must be one of {1}"  # noqa: E501
                .format(instance_type, allowed_values)
            )

        self._instance_type = instance_type

    @property
    def page_number(self):
        """Gets the page_number of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The page_number of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this DescribeDBInstancesRequest.


        :param page_number: The page_number of this DescribeDBInstancesRequest.  # noqa: E501
        :type: int
        """

        self._page_number = page_number

    @property
    def page_size(self):
        """Gets the page_size of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The page_size of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this DescribeDBInstancesRequest.


        :param page_size: The page_size of this DescribeDBInstancesRequest.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def tag_filters(self):
        """Gets the tag_filters of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The tag_filters of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: list[TagFilterForDescribeDBInstancesInput]
        """
        return self._tag_filters

    @tag_filters.setter
    def tag_filters(self, tag_filters):
        """Sets the tag_filters of this DescribeDBInstancesRequest.


        :param tag_filters: The tag_filters of this DescribeDBInstancesRequest.  # noqa: E501
        :type: list[TagFilterForDescribeDBInstancesInput]
        """

        self._tag_filters = tag_filters

    @property
    def update_end_time(self):
        """Gets the update_end_time of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The update_end_time of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._update_end_time

    @update_end_time.setter
    def update_end_time(self, update_end_time):
        """Sets the update_end_time of this DescribeDBInstancesRequest.


        :param update_end_time: The update_end_time of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._update_end_time = update_end_time

    @property
    def update_start_time(self):
        """Gets the update_start_time of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The update_start_time of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._update_start_time

    @update_start_time.setter
    def update_start_time(self, update_start_time):
        """Sets the update_start_time of this DescribeDBInstancesRequest.


        :param update_start_time: The update_start_time of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._update_start_time = update_start_time

    @property
    def vpc_id(self):
        """Gets the vpc_id of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The vpc_id of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this DescribeDBInstancesRequest.


        :param vpc_id: The vpc_id of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    @property
    def zone_id(self):
        """Gets the zone_id of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The zone_id of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this DescribeDBInstancesRequest.


        :param zone_id: The zone_id of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeDBInstancesRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeDBInstancesRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeDBInstancesRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    vpn

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from volcenginesdkvpn.models.create_customer_gateway_request import CreateCustomerGatewayRequest
from volcenginesdkvpn.models.create_customer_gateway_response import CreateCustomerGatewayResponse
from volcenginesdkvpn.models.create_vpn_connection_request import CreateVpnConnectionRequest
from volcenginesdkvpn.models.create_vpn_connection_response import CreateVpnConnectionResponse
from volcenginesdkvpn.models.create_vpn_gateway_request import CreateVpnGatewayRequest
from volcenginesdkvpn.models.create_vpn_gateway_response import CreateVpnGatewayResponse
from volcenginesdkvpn.models.create_vpn_gateway_route_request import CreateVpnGatewayRouteRequest
from volcenginesdkvpn.models.create_vpn_gateway_route_response import CreateVpnGatewayRouteResponse
from volcenginesdkvpn.models.customer_gateway_for_describe_customer_gateways_output import CustomerGatewayForDescribeCustomerGatewaysOutput
from volcenginesdkvpn.models.delete_customer_gateway_request import DeleteCustomerGatewayRequest
from volcenginesdkvpn.models.delete_customer_gateway_response import DeleteCustomerGatewayResponse
from volcenginesdkvpn.models.delete_vpn_connection_request import DeleteVpnConnectionRequest
from volcenginesdkvpn.models.delete_vpn_connection_response import DeleteVpnConnectionResponse
from volcenginesdkvpn.models.delete_vpn_gateway_request import DeleteVpnGatewayRequest
from volcenginesdkvpn.models.delete_vpn_gateway_response import DeleteVpnGatewayResponse
from volcenginesdkvpn.models.delete_vpn_gateway_route_request import DeleteVpnGatewayRouteRequest
from volcenginesdkvpn.models.delete_vpn_gateway_route_response import DeleteVpnGatewayRouteResponse
from volcenginesdkvpn.models.describe_customer_gateway_attributes_request import DescribeCustomerGatewayAttributesRequest
from volcenginesdkvpn.models.describe_customer_gateway_attributes_response import DescribeCustomerGatewayAttributesResponse
from volcenginesdkvpn.models.describe_customer_gateways_request import DescribeCustomerGatewaysRequest
from volcenginesdkvpn.models.describe_customer_gateways_response import DescribeCustomerGatewaysResponse
from volcenginesdkvpn.models.describe_vpn_connection_attributes_request import DescribeVpnConnectionAttributesRequest
from volcenginesdkvpn.models.describe_vpn_connection_attributes_response import DescribeVpnConnectionAttributesResponse
from volcenginesdkvpn.models.describe_vpn_connections_request import DescribeVpnConnectionsRequest
from volcenginesdkvpn.models.describe_vpn_connections_response import DescribeVpnConnectionsResponse
from volcenginesdkvpn.models.describe_vpn_gateway_attributes_request import DescribeVpnGatewayAttributesRequest
from volcenginesdkvpn.models.describe_vpn_gateway_attributes_response import DescribeVpnGatewayAttributesResponse
from volcenginesdkvpn.models.describe_vpn_gateway_route_attributes_request import DescribeVpnGatewayRouteAttributesRequest
from volcenginesdkvpn.models.describe_vpn_gateway_route_attributes_response import DescribeVpnGatewayRouteAttributesResponse
from volcenginesdkvpn.models.describe_vpn_gateway_routes_request import DescribeVpnGatewayRoutesRequest
from volcenginesdkvpn.models.describe_vpn_gateway_routes_response import DescribeVpnGatewayRoutesResponse
from volcenginesdkvpn.models.describe_vpn_gateways_billing_request import DescribeVpnGatewaysBillingRequest
from volcenginesdkvpn.models.describe_vpn_gateways_billing_response import DescribeVpnGatewaysBillingResponse
from volcenginesdkvpn.models.describe_vpn_gateways_request import DescribeVpnGatewaysRequest
from volcenginesdkvpn.models.describe_vpn_gateways_response import DescribeVpnGatewaysResponse
from volcenginesdkvpn.models.ike_config_for_describe_vpn_connection_attributes_output import IkeConfigForDescribeVpnConnectionAttributesOutput
from volcenginesdkvpn.models.ike_config_for_describe_vpn_connections_output import IkeConfigForDescribeVpnConnectionsOutput
from volcenginesdkvpn.models.ipsec_config_for_describe_vpn_connection_attributes_output import IpsecConfigForDescribeVpnConnectionAttributesOutput
from volcenginesdkvpn.models.ipsec_config_for_describe_vpn_connections_output import IpsecConfigForDescribeVpnConnectionsOutput
from volcenginesdkvpn.models.modify_customer_gateway_attributes_request import ModifyCustomerGatewayAttributesRequest
from volcenginesdkvpn.models.modify_customer_gateway_attributes_response import ModifyCustomerGatewayAttributesResponse
from volcenginesdkvpn.models.modify_vpn_connection_attributes_request import ModifyVpnConnectionAttributesRequest
from volcenginesdkvpn.models.modify_vpn_connection_attributes_response import ModifyVpnConnectionAttributesResponse
from volcenginesdkvpn.models.modify_vpn_gateway_attributes_request import ModifyVpnGatewayAttributesRequest
from volcenginesdkvpn.models.modify_vpn_gateway_attributes_response import ModifyVpnGatewayAttributesResponse
from volcenginesdkvpn.models.renew_vpn_gateway_request import RenewVpnGatewayRequest
from volcenginesdkvpn.models.renew_vpn_gateway_response import RenewVpnGatewayResponse
from volcenginesdkvpn.models.set_vpn_gateway_renewal_request import SetVpnGatewayRenewalRequest
from volcenginesdkvpn.models.set_vpn_gateway_renewal_response import SetVpnGatewayRenewalResponse
from volcenginesdkvpn.models.tag_filter_for_describe_vpn_gateways_input import TagFilterForDescribeVpnGatewaysInput
from volcenginesdkvpn.models.tag_for_create_vpn_gateway_input import TagForCreateVpnGatewayInput
from volcenginesdkvpn.models.tag_for_describe_vpn_gateway_attributes_output import TagForDescribeVpnGatewayAttributesOutput
from volcenginesdkvpn.models.tag_for_describe_vpn_gateways_output import TagForDescribeVpnGatewaysOutput
from volcenginesdkvpn.models.vpn_connection_for_describe_vpn_connections_output import VpnConnectionForDescribeVpnConnectionsOutput
from volcenginesdkvpn.models.vpn_gateway_for_describe_vpn_gateways_billing_output import VpnGatewayForDescribeVpnGatewaysBillingOutput
from volcenginesdkvpn.models.vpn_gateway_for_describe_vpn_gateways_output import VpnGatewayForDescribeVpnGatewaysOutput
from volcenginesdkvpn.models.vpn_gateway_route_for_describe_vpn_gateway_routes_output import VpnGatewayRouteForDescribeVpnGatewayRoutesOutput



# coding: utf-8

"""
    vpn

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class VpnGatewayForDescribeVpnGatewaysBillingOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'billing_status': 'int',
        'billing_type': 'int',
        'expired_time': 'str',
        'reclaim_time': 'str',
        'remain_renew_times': 'int',
        'renew_type': 'int',
        'vpn_gateway_id': 'str'
    }

    attribute_map = {
        'billing_status': 'BillingStatus',
        'billing_type': 'BillingType',
        'expired_time': 'ExpiredTime',
        'reclaim_time': 'ReclaimTime',
        'remain_renew_times': 'RemainRenewTimes',
        'renew_type': 'RenewType',
        'vpn_gateway_id': 'VpnGatewayId'
    }

    def __init__(self, billing_status=None, billing_type=None, expired_time=None, reclaim_time=None, remain_renew_times=None, renew_type=None, vpn_gateway_id=None, _configuration=None):  # noqa: E501
        """VpnGatewayForDescribeVpnGatewaysBillingOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._billing_status = None
        self._billing_type = None
        self._expired_time = None
        self._reclaim_time = None
        self._remain_renew_times = None
        self._renew_type = None
        self._vpn_gateway_id = None
        self.discriminator = None

        if billing_status is not None:
            self.billing_status = billing_status
        if billing_type is not None:
            self.billing_type = billing_type
        if expired_time is not None:
            self.expired_time = expired_time
        if reclaim_time is not None:
            self.reclaim_time = reclaim_time
        if remain_renew_times is not None:
            self.remain_renew_times = remain_renew_times
        if renew_type is not None:
            self.renew_type = renew_type
        if vpn_gateway_id is not None:
            self.vpn_gateway_id = vpn_gateway_id

    @property
    def billing_status(self):
        """Gets the billing_status of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501


        :return: The billing_status of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501
        :rtype: int
        """
        return self._billing_status

    @billing_status.setter
    def billing_status(self, billing_status):
        """Sets the billing_status of this VpnGatewayForDescribeVpnGatewaysBillingOutput.


        :param billing_status: The billing_status of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501
        :type: int
        """

        self._billing_status = billing_status

    @property
    def billing_type(self):
        """Gets the billing_type of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501


        :return: The billing_type of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501
        :rtype: int
        """
        return self._billing_type

    @billing_type.setter
    def billing_type(self, billing_type):
        """Sets the billing_type of this VpnGatewayForDescribeVpnGatewaysBillingOutput.


        :param billing_type: The billing_type of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501
        :type: int
        """

        self._billing_type = billing_type

    @property
    def expired_time(self):
        """Gets the expired_time of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501


        :return: The expired_time of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501
        :rtype: str
        """
        return self._expired_time

    @expired_time.setter
    def expired_time(self, expired_time):
        """Sets the expired_time of this VpnGatewayForDescribeVpnGatewaysBillingOutput.


        :param expired_time: The expired_time of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501
        :type: str
        """

        self._expired_time = expired_time

    @property
    def reclaim_time(self):
        """Gets the reclaim_time of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501


        :return: The reclaim_time of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501
        :rtype: str
        """
        return self._reclaim_time

    @reclaim_time.setter
    def reclaim_time(self, reclaim_time):
        """Sets the reclaim_time of this VpnGatewayForDescribeVpnGatewaysBillingOutput.


        :param reclaim_time: The reclaim_time of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501
        :type: str
        """

        self._reclaim_time = reclaim_time

    @property
    def remain_renew_times(self):
        """Gets the remain_renew_times of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501


        :return: The remain_renew_times of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501
        :rtype: int
        """
        return self._remain_renew_times

    @remain_renew_times.setter
    def remain_renew_times(self, remain_renew_times):
        """Sets the remain_renew_times of this VpnGatewayForDescribeVpnGatewaysBillingOutput.


        :param remain_renew_times: The remain_renew_times of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501
        :type: int
        """

        self._remain_renew_times = remain_renew_times

    @property
    def renew_type(self):
        """Gets the renew_type of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501


        :return: The renew_type of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501
        :rtype: int
        """
        return self._renew_type

    @renew_type.setter
    def renew_type(self, renew_type):
        """Sets the renew_type of this VpnGatewayForDescribeVpnGatewaysBillingOutput.


        :param renew_type: The renew_type of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501
        :type: int
        """

        self._renew_type = renew_type

    @property
    def vpn_gateway_id(self):
        """Gets the vpn_gateway_id of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501


        :return: The vpn_gateway_id of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501
        :rtype: str
        """
        return self._vpn_gateway_id

    @vpn_gateway_id.setter
    def vpn_gateway_id(self, vpn_gateway_id):
        """Sets the vpn_gateway_id of this VpnGatewayForDescribeVpnGatewaysBillingOutput.


        :param vpn_gateway_id: The vpn_gateway_id of this VpnGatewayForDescribeVpnGatewaysBillingOutput.  # noqa: E501
        :type: str
        """

        self._vpn_gateway_id = vpn_gateway_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VpnGatewayForDescribeVpnGatewaysBillingOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VpnGatewayForDescribeVpnGatewaysBillingOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VpnGatewayForDescribeVpnGatewaysBillingOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ecs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeImagesRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'image_ids': 'list[str]',
        'image_status': 'str',
        'instance_type_id': 'str',
        'is_support_cloud_init': 'bool',
        'max_results': 'int',
        'next_token': 'str',
        'os_type': 'str',
        'project_name': 'str',
        'status': 'list[str]',
        'visibility': 'str'
    }

    attribute_map = {
        'image_ids': 'ImageIds',
        'image_status': 'ImageStatus',
        'instance_type_id': 'InstanceTypeId',
        'is_support_cloud_init': 'IsSupportCloudInit',
        'max_results': 'MaxResults',
        'next_token': 'NextToken',
        'os_type': 'OsType',
        'project_name': 'ProjectName',
        'status': 'Status',
        'visibility': 'Visibility'
    }

    def __init__(self, image_ids=None, image_status=None, instance_type_id=None, is_support_cloud_init=None, max_results=None, next_token=None, os_type=None, project_name=None, status=None, visibility=None, _configuration=None):  # noqa: E501
        """DescribeImagesRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._image_ids = None
        self._image_status = None
        self._instance_type_id = None
        self._is_support_cloud_init = None
        self._max_results = None
        self._next_token = None
        self._os_type = None
        self._project_name = None
        self._status = None
        self._visibility = None
        self.discriminator = None

        if image_ids is not None:
            self.image_ids = image_ids
        if image_status is not None:
            self.image_status = image_status
        if instance_type_id is not None:
            self.instance_type_id = instance_type_id
        if is_support_cloud_init is not None:
            self.is_support_cloud_init = is_support_cloud_init
        if max_results is not None:
            self.max_results = max_results
        if next_token is not None:
            self.next_token = next_token
        if os_type is not None:
            self.os_type = os_type
        if project_name is not None:
            self.project_name = project_name
        if status is not None:
            self.status = status
        if visibility is not None:
            self.visibility = visibility

    @property
    def image_ids(self):
        """Gets the image_ids of this DescribeImagesRequest.  # noqa: E501


        :return: The image_ids of this DescribeImagesRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._image_ids

    @image_ids.setter
    def image_ids(self, image_ids):
        """Sets the image_ids of this DescribeImagesRequest.


        :param image_ids: The image_ids of this DescribeImagesRequest.  # noqa: E501
        :type: list[str]
        """

        self._image_ids = image_ids

    @property
    def image_status(self):
        """Gets the image_status of this DescribeImagesRequest.  # noqa: E501


        :return: The image_status of this DescribeImagesRequest.  # noqa: E501
        :rtype: str
        """
        return self._image_status

    @image_status.setter
    def image_status(self, image_status):
        """Sets the image_status of this DescribeImagesRequest.


        :param image_status: The image_status of this DescribeImagesRequest.  # noqa: E501
        :type: str
        """

        self._image_status = image_status

    @property
    def instance_type_id(self):
        """Gets the instance_type_id of this DescribeImagesRequest.  # noqa: E501


        :return: The instance_type_id of this DescribeImagesRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_type_id

    @instance_type_id.setter
    def instance_type_id(self, instance_type_id):
        """Sets the instance_type_id of this DescribeImagesRequest.


        :param instance_type_id: The instance_type_id of this DescribeImagesRequest.  # noqa: E501
        :type: str
        """

        self._instance_type_id = instance_type_id

    @property
    def is_support_cloud_init(self):
        """Gets the is_support_cloud_init of this DescribeImagesRequest.  # noqa: E501


        :return: The is_support_cloud_init of this DescribeImagesRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_support_cloud_init

    @is_support_cloud_init.setter
    def is_support_cloud_init(self, is_support_cloud_init):
        """Sets the is_support_cloud_init of this DescribeImagesRequest.


        :param is_support_cloud_init: The is_support_cloud_init of this DescribeImagesRequest.  # noqa: E501
        :type: bool
        """

        self._is_support_cloud_init = is_support_cloud_init

    @property
    def max_results(self):
        """Gets the max_results of this DescribeImagesRequest.  # noqa: E501


        :return: The max_results of this DescribeImagesRequest.  # noqa: E501
        :rtype: int
        """
        return self._max_results

    @max_results.setter
    def max_results(self, max_results):
        """Sets the max_results of this DescribeImagesRequest.


        :param max_results: The max_results of this DescribeImagesRequest.  # noqa: E501
        :type: int
        """

        self._max_results = max_results

    @property
    def next_token(self):
        """Gets the next_token of this DescribeImagesRequest.  # noqa: E501


        :return: The next_token of this DescribeImagesRequest.  # noqa: E501
        :rtype: str
        """
        return self._next_token

    @next_token.setter
    def next_token(self, next_token):
        """Sets the next_token of this DescribeImagesRequest.


        :param next_token: The next_token of this DescribeImagesRequest.  # noqa: E501
        :type: str
        """

        self._next_token = next_token

    @property
    def os_type(self):
        """Gets the os_type of this DescribeImagesRequest.  # noqa: E501


        :return: The os_type of this DescribeImagesRequest.  # noqa: E501
        :rtype: str
        """
        return self._os_type

    @os_type.setter
    def os_type(self, os_type):
        """Sets the os_type of this DescribeImagesRequest.


        :param os_type: The os_type of this DescribeImagesRequest.  # noqa: E501
        :type: str
        """

        self._os_type = os_type

    @property
    def project_name(self):
        """Gets the project_name of this DescribeImagesRequest.  # noqa: E501


        :return: The project_name of this DescribeImagesRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this DescribeImagesRequest.


        :param project_name: The project_name of this DescribeImagesRequest.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def status(self):
        """Gets the status of this DescribeImagesRequest.  # noqa: E501


        :return: The status of this DescribeImagesRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DescribeImagesRequest.


        :param status: The status of this DescribeImagesRequest.  # noqa: E501
        :type: list[str]
        """

        self._status = status

    @property
    def visibility(self):
        """Gets the visibility of this DescribeImagesRequest.  # noqa: E501


        :return: The visibility of this DescribeImagesRequest.  # noqa: E501
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this DescribeImagesRequest.


        :param visibility: The visibility of this DescribeImagesRequest.  # noqa: E501
        :type: str
        """

        self._visibility = visibility

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeImagesRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeImagesRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeImagesRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vpn

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class IkeConfigForDescribeVpnConnectionAttributesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auth_alg': 'str',
        'dh_group': 'str',
        'enc_alg': 'str',
        'lifetime': 'int',
        'local_id': 'str',
        'mode': 'str',
        'psk': 'str',
        'remote_id': 'str',
        'version': 'str'
    }

    attribute_map = {
        'auth_alg': 'AuthAlg',
        'dh_group': 'DhGroup',
        'enc_alg': 'EncAlg',
        'lifetime': 'Lifetime',
        'local_id': 'LocalId',
        'mode': 'Mode',
        'psk': 'Psk',
        'remote_id': 'RemoteId',
        'version': 'Version'
    }

    def __init__(self, auth_alg=None, dh_group=None, enc_alg=None, lifetime=None, local_id=None, mode=None, psk=None, remote_id=None, version=None, _configuration=None):  # noqa: E501
        """IkeConfigForDescribeVpnConnectionAttributesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._auth_alg = None
        self._dh_group = None
        self._enc_alg = None
        self._lifetime = None
        self._local_id = None
        self._mode = None
        self._psk = None
        self._remote_id = None
        self._version = None
        self.discriminator = None

        if auth_alg is not None:
            self.auth_alg = auth_alg
        if dh_group is not None:
            self.dh_group = dh_group
        if enc_alg is not None:
            self.enc_alg = enc_alg
        if lifetime is not None:
            self.lifetime = lifetime
        if local_id is not None:
            self.local_id = local_id
        if mode is not None:
            self.mode = mode
        if psk is not None:
            self.psk = psk
        if remote_id is not None:
            self.remote_id = remote_id
        if version is not None:
            self.version = version

    @property
    def auth_alg(self):
        """Gets the auth_alg of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501


        :return: The auth_alg of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :rtype: str
        """
        return self._auth_alg

    @auth_alg.setter
    def auth_alg(self, auth_alg):
        """Sets the auth_alg of this IkeConfigForDescribeVpnConnectionAttributesOutput.


        :param auth_alg: The auth_alg of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :type: str
        """

        self._auth_alg = auth_alg

    @property
    def dh_group(self):
        """Gets the dh_group of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501


        :return: The dh_group of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :rtype: str
        """
        return self._dh_group

    @dh_group.setter
    def dh_group(self, dh_group):
        """Sets the dh_group of this IkeConfigForDescribeVpnConnectionAttributesOutput.


        :param dh_group: The dh_group of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :type: str
        """

        self._dh_group = dh_group

    @property
    def enc_alg(self):
        """Gets the enc_alg of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501


        :return: The enc_alg of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :rtype: str
        """
        return self._enc_alg

    @enc_alg.setter
    def enc_alg(self, enc_alg):
        """Sets the enc_alg of this IkeConfigForDescribeVpnConnectionAttributesOutput.


        :param enc_alg: The enc_alg of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :type: str
        """

        self._enc_alg = enc_alg

    @property
    def lifetime(self):
        """Gets the lifetime of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501


        :return: The lifetime of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :rtype: int
        """
        return self._lifetime

    @lifetime.setter
    def lifetime(self, lifetime):
        """Sets the lifetime of this IkeConfigForDescribeVpnConnectionAttributesOutput.


        :param lifetime: The lifetime of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :type: int
        """

        self._lifetime = lifetime

    @property
    def local_id(self):
        """Gets the local_id of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501


        :return: The local_id of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :rtype: str
        """
        return self._local_id

    @local_id.setter
    def local_id(self, local_id):
        """Sets the local_id of this IkeConfigForDescribeVpnConnectionAttributesOutput.


        :param local_id: The local_id of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :type: str
        """

        self._local_id = local_id

    @property
    def mode(self):
        """Gets the mode of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501


        :return: The mode of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this IkeConfigForDescribeVpnConnectionAttributesOutput.


        :param mode: The mode of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :type: str
        """

        self._mode = mode

    @property
    def psk(self):
        """Gets the psk of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501


        :return: The psk of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :rtype: str
        """
        return self._psk

    @psk.setter
    def psk(self, psk):
        """Sets the psk of this IkeConfigForDescribeVpnConnectionAttributesOutput.


        :param psk: The psk of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :type: str
        """

        self._psk = psk

    @property
    def remote_id(self):
        """Gets the remote_id of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501


        :return: The remote_id of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :rtype: str
        """
        return self._remote_id

    @remote_id.setter
    def remote_id(self, remote_id):
        """Sets the remote_id of this IkeConfigForDescribeVpnConnectionAttributesOutput.


        :param remote_id: The remote_id of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :type: str
        """

        self._remote_id = remote_id

    @property
    def version(self):
        """Gets the version of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501


        :return: The version of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this IkeConfigForDescribeVpnConnectionAttributesOutput.


        :param version: The version of this IkeConfigForDescribeVpnConnectionAttributesOutput.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IkeConfigForDescribeVpnConnectionAttributesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IkeConfigForDescribeVpnConnectionAttributesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IkeConfigForDescribeVpnConnectionAttributesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vke

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ClusterConfigForListClustersOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'api_server_endpoints': 'ApiServerEndpointsForListClustersOutput',
        'api_server_public_access_config': 'ApiServerPublicAccessConfigForListClustersOutput',
        'api_server_public_access_enabled': 'bool',
        'resource_public_access_default_enabled': 'bool',
        'security_group_ids': 'list[str]',
        'subnet_ids': 'list[str]',
        'vpc_id': 'str'
    }

    attribute_map = {
        'api_server_endpoints': 'ApiServerEndpoints',
        'api_server_public_access_config': 'ApiServerPublicAccessConfig',
        'api_server_public_access_enabled': 'ApiServerPublicAccessEnabled',
        'resource_public_access_default_enabled': 'ResourcePublicAccessDefaultEnabled',
        'security_group_ids': 'SecurityGroupIds',
        'subnet_ids': 'SubnetIds',
        'vpc_id': 'VpcId'
    }

    def __init__(self, api_server_endpoints=None, api_server_public_access_config=None, api_server_public_access_enabled=None, resource_public_access_default_enabled=None, security_group_ids=None, subnet_ids=None, vpc_id=None, _configuration=None):  # noqa: E501
        """ClusterConfigForListClustersOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._api_server_endpoints = None
        self._api_server_public_access_config = None
        self._api_server_public_access_enabled = None
        self._resource_public_access_default_enabled = None
        self._security_group_ids = None
        self._subnet_ids = None
        self._vpc_id = None
        self.discriminator = None

        if api_server_endpoints is not None:
            self.api_server_endpoints = api_server_endpoints
        if api_server_public_access_config is not None:
            self.api_server_public_access_config = api_server_public_access_config
        if api_server_public_access_enabled is not None:
            self.api_server_public_access_enabled = api_server_public_access_enabled
        if resource_public_access_default_enabled is not None:
            self.resource_public_access_default_enabled = resource_public_access_default_enabled
        if security_group_ids is not None:
            self.security_group_ids = security_group_ids
        if subnet_ids is not None:
            self.subnet_ids = subnet_ids
        if vpc_id is not None:
            self.vpc_id = vpc_id

    @property
    def api_server_endpoints(self):
        """Gets the api_server_endpoints of this ClusterConfigForListClustersOutput.  # noqa: E501


        :return: The api_server_endpoints of this ClusterConfigForListClustersOutput.  # noqa: E501
        :rtype: ApiServerEndpointsForListClustersOutput
        """
        return self._api_server_endpoints

    @api_server_endpoints.setter
    def api_server_endpoints(self, api_server_endpoints):
        """Sets the api_server_endpoints of this ClusterConfigForListClustersOutput.


        :param api_server_endpoints: The api_server_endpoints of this ClusterConfigForListClustersOutput.  # noqa: E501
        :type: ApiServerEndpointsForListClustersOutput
        """

        self._api_server_endpoints = api_server_endpoints

    @property
    def api_server_public_access_config(self):
        """Gets the api_server_public_access_config of this ClusterConfigForListClustersOutput.  # noqa: E501


        :return: The api_server_public_access_config of this ClusterConfigForListClustersOutput.  # noqa: E501
        :rtype: ApiServerPublicAccessConfigForListClustersOutput
        """
        return self._api_server_public_access_config

    @api_server_public_access_config.setter
    def api_server_public_access_config(self, api_server_public_access_config):
        """Sets the api_server_public_access_config of this ClusterConfigForListClustersOutput.


        :param api_server_public_access_config: The api_server_public_access_config of this ClusterConfigForListClustersOutput.  # noqa: E501
        :type: ApiServerPublicAccessConfigForListClustersOutput
        """

        self._api_server_public_access_config = api_server_public_access_config

    @property
    def api_server_public_access_enabled(self):
        """Gets the api_server_public_access_enabled of this ClusterConfigForListClustersOutput.  # noqa: E501


        :return: The api_server_public_access_enabled of this ClusterConfigForListClustersOutput.  # noqa: E501
        :rtype: bool
        """
        return self._api_server_public_access_enabled

    @api_server_public_access_enabled.setter
    def api_server_public_access_enabled(self, api_server_public_access_enabled):
        """Sets the api_server_public_access_enabled of this ClusterConfigForListClustersOutput.


        :param api_server_public_access_enabled: The api_server_public_access_enabled of this ClusterConfigForListClustersOutput.  # noqa: E501
        :type: bool
        """

        self._api_server_public_access_enabled = api_server_public_access_enabled

    @property
    def resource_public_access_default_enabled(self):
        """Gets the resource_public_access_default_enabled of this ClusterConfigForListClustersOutput.  # noqa: E501


        :return: The resource_public_access_default_enabled of this ClusterConfigForListClustersOutput.  # noqa: E501
        :rtype: bool
        """
        return self._resource_public_access_default_enabled

    @resource_public_access_default_enabled.setter
    def resource_public_access_default_enabled(self, resource_public_access_default_enabled):
        """Sets the resource_public_access_default_enabled of this ClusterConfigForListClustersOutput.


        :param resource_public_access_default_enabled: The resource_public_access_default_enabled of this ClusterConfigForListClustersOutput.  # noqa: E501
        :type: bool
        """

        self._resource_public_access_default_enabled = resource_public_access_default_enabled

    @property
    def security_group_ids(self):
        """Gets the security_group_ids of this ClusterConfigForListClustersOutput.  # noqa: E501


        :return: The security_group_ids of this ClusterConfigForListClustersOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._security_group_ids

    @security_group_ids.setter
    def security_group_ids(self, security_group_ids):
        """Sets the security_group_ids of this ClusterConfigForListClustersOutput.


        :param security_group_ids: The security_group_ids of this ClusterConfigForListClustersOutput.  # noqa: E501
        :type: list[str]
        """

        self._security_group_ids = security_group_ids

    @property
    def subnet_ids(self):
        """Gets the subnet_ids of this ClusterConfigForListClustersOutput.  # noqa: E501


        :return: The subnet_ids of this ClusterConfigForListClustersOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._subnet_ids

    @subnet_ids.setter
    def subnet_ids(self, subnet_ids):
        """Sets the subnet_ids of this ClusterConfigForListClustersOutput.


        :param subnet_ids: The subnet_ids of this ClusterConfigForListClustersOutput.  # noqa: E501
        :type: list[str]
        """

        self._subnet_ids = subnet_ids

    @property
    def vpc_id(self):
        """Gets the vpc_id of this ClusterConfigForListClustersOutput.  # noqa: E501


        :return: The vpc_id of this ClusterConfigForListClustersOutput.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this ClusterConfigForListClustersOutput.


        :param vpc_id: The vpc_id of this ClusterConfigForListClustersOutput.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ClusterConfigForListClustersOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClusterConfigForListClustersOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ClusterConfigForListClustersOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    vke

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from volcenginesdkvke.api.vke_api import VKEApi

# import models into sdk package
from volcenginesdkvke.models.api_server_endpoints_for_list_clusters_output import ApiServerEndpointsForListClustersOutput
from volcenginesdkvke.models.api_server_public_access_config_for_create_cluster_input import ApiServerPublicAccessConfigForCreateClusterInput
from volcenginesdkvke.models.api_server_public_access_config_for_list_clusters_output import ApiServerPublicAccessConfigForListClustersOutput
from volcenginesdkvke.models.api_server_public_access_config_for_update_cluster_config_input import ApiServerPublicAccessConfigForUpdateClusterConfigInput
from volcenginesdkvke.models.auto_scaling_for_create_node_pool_input import AutoScalingForCreateNodePoolInput
from volcenginesdkvke.models.auto_scaling_for_list_node_pools_output import AutoScalingForListNodePoolsOutput
from volcenginesdkvke.models.auto_scaling_for_update_node_pool_config_input import AutoScalingForUpdateNodePoolConfigInput
from volcenginesdkvke.models.cluster_config_for_create_cluster_input import ClusterConfigForCreateClusterInput
from volcenginesdkvke.models.cluster_config_for_list_clusters_output import ClusterConfigForListClustersOutput
from volcenginesdkvke.models.cluster_config_for_update_cluster_config_input import ClusterConfigForUpdateClusterConfigInput
from volcenginesdkvke.models.compatibility_for_list_supported_addons_output import CompatibilityForListSupportedAddonsOutput
from volcenginesdkvke.models.condition_for_list_addons_output import ConditionForListAddonsOutput
from volcenginesdkvke.models.condition_for_list_clusters_output import ConditionForListClustersOutput
from volcenginesdkvke.models.condition_for_list_node_pools_output import ConditionForListNodePoolsOutput
from volcenginesdkvke.models.condition_for_list_nodes_output import ConditionForListNodesOutput
from volcenginesdkvke.models.convert_tag_for_list_node_pools_output import ConvertTagForListNodePoolsOutput
from volcenginesdkvke.models.create_addon_request import CreateAddonRequest
from volcenginesdkvke.models.create_addon_response import CreateAddonResponse
from volcenginesdkvke.models.create_cluster_request import CreateClusterRequest
from volcenginesdkvke.models.create_cluster_response import CreateClusterResponse
from volcenginesdkvke.models.create_default_node_pool_request import CreateDefaultNodePoolRequest
from volcenginesdkvke.models.create_default_node_pool_response import CreateDefaultNodePoolResponse
from volcenginesdkvke.models.create_kubeconfig_request import CreateKubeconfigRequest
from volcenginesdkvke.models.create_kubeconfig_response import CreateKubeconfigResponse
from volcenginesdkvke.models.create_node_pool_request import CreateNodePoolRequest
from volcenginesdkvke.models.create_node_pool_response import CreateNodePoolResponse
from volcenginesdkvke.models.create_nodes_request import CreateNodesRequest
from volcenginesdkvke.models.create_nodes_response import CreateNodesResponse
from volcenginesdkvke.models.data_volume_for_create_node_pool_input import DataVolumeForCreateNodePoolInput
from volcenginesdkvke.models.data_volume_for_list_node_pools_output import DataVolumeForListNodePoolsOutput
from volcenginesdkvke.models.data_volume_for_update_node_pool_config_input import DataVolumeForUpdateNodePoolConfigInput
from volcenginesdkvke.models.delete_addon_request import DeleteAddonRequest
from volcenginesdkvke.models.delete_addon_response import DeleteAddonResponse
from volcenginesdkvke.models.delete_cluster_request import DeleteClusterRequest
from volcenginesdkvke.models.delete_cluster_response import DeleteClusterResponse
from volcenginesdkvke.models.delete_kubeconfigs_request import DeleteKubeconfigsRequest
from volcenginesdkvke.models.delete_kubeconfigs_response import DeleteKubeconfigsResponse
from volcenginesdkvke.models.delete_node_pool_request import DeleteNodePoolRequest
from volcenginesdkvke.models.delete_node_pool_response import DeleteNodePoolResponse
from volcenginesdkvke.models.delete_nodes_request import DeleteNodesRequest
from volcenginesdkvke.models.delete_nodes_response import DeleteNodesResponse
from volcenginesdkvke.models.filter_for_list_addons_input import FilterForListAddonsInput
from volcenginesdkvke.models.filter_for_list_clusters_input import FilterForListClustersInput
from volcenginesdkvke.models.filter_for_list_kubeconfigs_input import FilterForListKubeconfigsInput
from volcenginesdkvke.models.filter_for_list_node_pools_input import FilterForListNodePoolsInput
from volcenginesdkvke.models.filter_for_list_nodes_input import FilterForListNodesInput
from volcenginesdkvke.models.filter_for_list_supported_addons_input import FilterForListSupportedAddonsInput
from volcenginesdkvke.models.filter_for_list_supported_resource_types_input import FilterForListSupportedResourceTypesInput
from volcenginesdkvke.models.flannel_config_for_create_cluster_input import FlannelConfigForCreateClusterInput
from volcenginesdkvke.models.flannel_config_for_list_clusters_output import FlannelConfigForListClustersOutput
from volcenginesdkvke.models.forward_kubernetes_api_request import ForwardKubernetesApiRequest
from volcenginesdkvke.models.forward_kubernetes_api_response import ForwardKubernetesApiResponse
from volcenginesdkvke.models.header_for_forward_kubernetes_api_input import HeaderForForwardKubernetesApiInput
from volcenginesdkvke.models.item_for_list_addons_output import ItemForListAddonsOutput
from volcenginesdkvke.models.item_for_list_clusters_output import ItemForListClustersOutput
from volcenginesdkvke.models.item_for_list_kubeconfigs_output import ItemForListKubeconfigsOutput
from volcenginesdkvke.models.item_for_list_node_pools_output import ItemForListNodePoolsOutput
from volcenginesdkvke.models.item_for_list_nodes_output import ItemForListNodesOutput
from volcenginesdkvke.models.item_for_list_supported_addons_output import ItemForListSupportedAddonsOutput
from volcenginesdkvke.models.item_for_list_supported_resource_types_output import ItemForListSupportedResourceTypesOutput
from volcenginesdkvke.models.kubernetes_config_for_create_default_node_pool_input import KubernetesConfigForCreateDefaultNodePoolInput
from volcenginesdkvke.models.kubernetes_config_for_create_node_pool_input import KubernetesConfigForCreateNodePoolInput
from volcenginesdkvke.models.kubernetes_config_for_create_nodes_input import KubernetesConfigForCreateNodesInput
from volcenginesdkvke.models.kubernetes_config_for_list_node_pools_output import KubernetesConfigForListNodePoolsOutput
from volcenginesdkvke.models.kubernetes_config_for_list_nodes_output import KubernetesConfigForListNodesOutput
from volcenginesdkvke.models.kubernetes_config_for_update_node_pool_config_input import KubernetesConfigForUpdateNodePoolConfigInput
from volcenginesdkvke.models.label_for_create_default_node_pool_input import LabelForCreateDefaultNodePoolInput
from volcenginesdkvke.models.label_for_create_node_pool_input import LabelForCreateNodePoolInput
from volcenginesdkvke.models.label_for_create_nodes_input import LabelForCreateNodesInput
from volcenginesdkvke.models.label_for_list_node_pools_output import LabelForListNodePoolsOutput
from volcenginesdkvke.models.label_for_list_nodes_output import LabelForListNodesOutput
from volcenginesdkvke.models.label_for_update_node_pool_config_input import LabelForUpdateNodePoolConfigInput
from volcenginesdkvke.models.list_addons_request import ListAddonsRequest
from volcenginesdkvke.models.list_addons_response import ListAddonsResponse
from volcenginesdkvke.models.list_clusters_request import ListClustersRequest
from volcenginesdkvke.models.list_clusters_response import ListClustersResponse
from volcenginesdkvke.models.list_kubeconfigs_request import ListKubeconfigsRequest
from volcenginesdkvke.models.list_kubeconfigs_response import ListKubeconfigsResponse
from volcenginesdkvke.models.list_node_pools_request import ListNodePoolsRequest
from volcenginesdkvke.models.list_node_pools_response import ListNodePoolsResponse
from volcenginesdkvke.models.list_nodes_request import ListNodesRequest
from volcenginesdkvke.models.list_nodes_response import ListNodesResponse
from volcenginesdkvke.models.list_supported_addons_request import ListSupportedAddonsRequest
from volcenginesdkvke.models.list_supported_addons_response import ListSupportedAddonsResponse
from volcenginesdkvke.models.list_supported_resource_types_request import ListSupportedResourceTypesRequest
from volcenginesdkvke.models.list_supported_resource_types_response import ListSupportedResourceTypesResponse
from volcenginesdkvke.models.list_tags_for_resources_request import ListTagsForResourcesRequest
from volcenginesdkvke.models.list_tags_for_resources_response import ListTagsForResourcesResponse
from volcenginesdkvke.models.login_for_create_default_node_pool_input import LoginForCreateDefaultNodePoolInput
from volcenginesdkvke.models.login_for_create_node_pool_input import LoginForCreateNodePoolInput
from volcenginesdkvke.models.login_for_list_node_pools_output import LoginForListNodePoolsOutput
from volcenginesdkvke.models.login_for_update_node_pool_config_input import LoginForUpdateNodePoolConfigInput
from volcenginesdkvke.models.node_config_for_create_default_node_pool_input import NodeConfigForCreateDefaultNodePoolInput
from volcenginesdkvke.models.node_config_for_create_node_pool_input import NodeConfigForCreateNodePoolInput
from volcenginesdkvke.models.node_config_for_list_node_pools_output import NodeConfigForListNodePoolsOutput
from volcenginesdkvke.models.node_config_for_update_node_pool_config_input import NodeConfigForUpdateNodePoolConfigInput
from volcenginesdkvke.models.node_statistics_for_list_clusters_output import NodeStatisticsForListClustersOutput
from volcenginesdkvke.models.node_statistics_for_list_node_pools_output import NodeStatisticsForListNodePoolsOutput
from volcenginesdkvke.models.pods_config_for_create_cluster_input import PodsConfigForCreateClusterInput
from volcenginesdkvke.models.pods_config_for_list_clusters_output import PodsConfigForListClustersOutput
from volcenginesdkvke.models.private_ip_for_list_clusters_output import PrivateIpForListClustersOutput
from volcenginesdkvke.models.public_access_network_config_for_create_cluster_input import PublicAccessNetworkConfigForCreateClusterInput
from volcenginesdkvke.models.public_access_network_config_for_list_clusters_output import PublicAccessNetworkConfigForListClustersOutput
from volcenginesdkvke.models.public_access_network_config_for_update_cluster_config_input import PublicAccessNetworkConfigForUpdateClusterConfigInput
from volcenginesdkvke.models.public_ip_for_list_clusters_output import PublicIpForListClustersOutput
from volcenginesdkvke.models.resource_tag_for_list_tags_for_resources_output import ResourceTagForListTagsForResourcesOutput
from volcenginesdkvke.models.security_for_create_default_node_pool_input import SecurityForCreateDefaultNodePoolInput
from volcenginesdkvke.models.security_for_create_node_pool_input import SecurityForCreateNodePoolInput
from volcenginesdkvke.models.security_for_list_node_pools_output import SecurityForListNodePoolsOutput
from volcenginesdkvke.models.security_for_update_node_pool_config_input import SecurityForUpdateNodePoolConfigInput
from volcenginesdkvke.models.services_config_for_create_cluster_input import ServicesConfigForCreateClusterInput
from volcenginesdkvke.models.services_config_for_list_clusters_output import ServicesConfigForListClustersOutput
from volcenginesdkvke.models.status_for_list_addons_input import StatusForListAddonsInput
from volcenginesdkvke.models.status_for_list_addons_output import StatusForListAddonsOutput
from volcenginesdkvke.models.status_for_list_clusters_input import StatusForListClustersInput
from volcenginesdkvke.models.status_for_list_clusters_output import StatusForListClustersOutput
from volcenginesdkvke.models.status_for_list_node_pools_input import StatusForListNodePoolsInput
from volcenginesdkvke.models.status_for_list_node_pools_output import StatusForListNodePoolsOutput
from volcenginesdkvke.models.status_for_list_nodes_input import StatusForListNodesInput
from volcenginesdkvke.models.status_for_list_nodes_output import StatusForListNodesOutput
from volcenginesdkvke.models.system_volume_for_create_node_pool_input import SystemVolumeForCreateNodePoolInput
from volcenginesdkvke.models.system_volume_for_list_node_pools_output import SystemVolumeForListNodePoolsOutput
from volcenginesdkvke.models.system_volume_for_update_node_pool_config_input import SystemVolumeForUpdateNodePoolConfigInput
from volcenginesdkvke.models.tag_filter_for_list_tags_for_resources_input import TagFilterForListTagsForResourcesInput
from volcenginesdkvke.models.tag_for_create_cluster_input import TagForCreateClusterInput
from volcenginesdkvke.models.tag_for_create_default_node_pool_input import TagForCreateDefaultNodePoolInput
from volcenginesdkvke.models.tag_for_create_node_pool_input import TagForCreateNodePoolInput
from volcenginesdkvke.models.tag_for_list_clusters_input import TagForListClustersInput
from volcenginesdkvke.models.tag_for_list_clusters_output import TagForListClustersOutput
from volcenginesdkvke.models.tag_for_list_node_pools_output import TagForListNodePoolsOutput
from volcenginesdkvke.models.tag_for_tag_resources_input import TagForTagResourcesInput
from volcenginesdkvke.models.tag_for_update_node_pool_config_input import TagForUpdateNodePoolConfigInput
from volcenginesdkvke.models.tag_resources_request import TagResourcesRequest
from volcenginesdkvke.models.tag_resources_response import TagResourcesResponse
from volcenginesdkvke.models.taint_for_create_default_node_pool_input import TaintForCreateDefaultNodePoolInput
from volcenginesdkvke.models.taint_for_create_node_pool_input import TaintForCreateNodePoolInput
from volcenginesdkvke.models.taint_for_create_nodes_input import TaintForCreateNodesInput
from volcenginesdkvke.models.taint_for_list_node_pools_output import TaintForListNodePoolsOutput
from volcenginesdkvke.models.taint_for_list_nodes_output import TaintForListNodesOutput
from volcenginesdkvke.models.taint_for_update_node_pool_config_input import TaintForUpdateNodePoolConfigInput
from volcenginesdkvke.models.untag_resources_request import UntagResourcesRequest
from volcenginesdkvke.models.untag_resources_response import UntagResourcesResponse
from volcenginesdkvke.models.update_addon_config_request import UpdateAddonConfigRequest
from volcenginesdkvke.models.update_addon_config_response import UpdateAddonConfigResponse
from volcenginesdkvke.models.update_addon_version_request import UpdateAddonVersionRequest
from volcenginesdkvke.models.update_addon_version_response import UpdateAddonVersionResponse
from volcenginesdkvke.models.update_cluster_config_request import UpdateClusterConfigRequest
from volcenginesdkvke.models.update_cluster_config_response import UpdateClusterConfigResponse
from volcenginesdkvke.models.update_node_pool_config_request import UpdateNodePoolConfigRequest
from volcenginesdkvke.models.update_node_pool_config_response import UpdateNodePoolConfigResponse
from volcenginesdkvke.models.version_for_list_supported_addons_output import VersionForListSupportedAddonsOutput
from volcenginesdkvke.models.vpc_cni_config_for_create_cluster_input import VpcCniConfigForCreateClusterInput
from volcenginesdkvke.models.vpc_cni_config_for_list_clusters_output import VpcCniConfigForListClustersOutput
